import {NgModule} from '@angular/core';
import {PreloadAllModules, RouterModule, Routes} from '@angular/router';

import {EnvironmentSpecificResolver} from './openaireLibrary/utils/properties/environmentSpecificResolver';
import {EnvironmentSpecificService} from './openaireLibrary/utils/properties/environment-specific.service';

import {OpenaireErrorPageComponent} from './error/errorPage.component';

const routes: Routes = [
  {
    path: 'reload',
    loadChildren: './reload/libReload.module#LibReloadModule',
    resolve: {envSpecific: EnvironmentSpecificResolver}
  },
  {
    path: 'user-info',
    loadChildren: './login/libUser.module#LibUserModule',
    resolve: {envSpecific: EnvironmentSpecificResolver}
  },
  {
    path: 'error',
    component: OpenaireErrorPageComponent,
    resolve: {envSpecific: EnvironmentSpecificResolver},
    data: {hasSidebar: false}
  },
  {
    path: 'admin',
    loadChildren: './home/home.module#HomeModule',
    resolve: {envSpecific: EnvironmentSpecificResolver}
  },
  {
    path: 'admin/:stakeholder',
    loadChildren: './stakeholder/stakeholder.module#StakeholderModule',
    resolve: {envSpecific: EnvironmentSpecificResolver}
  },
  {
    path: 'admin/:stakeholder/:topic',
    loadChildren: './topic/topic.module#TopicModule',
    resolve: {envSpecific: EnvironmentSpecificResolver}
  },

  /* Library paths*/
  {
    path: 'portals',
    loadChildren: './openaireLibrary/dashboard/portal/communities.module#CommunitiesModule',
    resolve: { envSpecific: EnvironmentSpecificResolver  }
  },
  {
    path: 'entities',
    loadChildren: './openaireLibrary/dashboard/entity/entities.module#EntitiesModule',
    resolve: { envSpecific: EnvironmentSpecificResolver  }
  },
  {
    path: 'classes',
    loadChildren: './openaireLibrary/dashboard/divId/divIds.module#DivIdsModule',
    resolve: { envSpecific: EnvironmentSpecificResolver  }
  },
  {
    path: 'classContents',
    loadChildren: './openaireLibrary/dashboard/divhelpcontent/div-help-contents.module#DivHelpContentsModule',
    resolve: { envSpecific: EnvironmentSpecificResolver  }
  },
  {
    path: 'classContents/new',
    loadChildren: './openaireLibrary/dashboard/divhelpcontent/new-div-help-content.module#NewDivHelpContentModule',
    resolve: { envSpecific: EnvironmentSpecificResolver  }
  },
  {
    path: 'classContents/edit',
    loadChildren: './openaireLibrary/dashboard/divhelpcontent/edit-div-help-content.module#EditDivHelpContentModule',
    resolve: { envSpecific: EnvironmentSpecificResolver  }
  },
  {
    path: 'helptexts',
    loadChildren: './openaireLibrary/dashboard/helpTexts/page-help-contents.module#PageHelpContentsModule',
    resolve: { envSpecific: EnvironmentSpecificResolver  }
  },
  {
    path: 'helptexts/new',
    loadChildren: './openaireLibrary/dashboard/helpTexts/new-page-help-content.module#NewPageHelpContentModule',
    resolve: { envSpecific: EnvironmentSpecificResolver  }
  },
  {
    path: 'helptexts/edit',
    loadChildren: './openaireLibrary/dashboard/helpTexts/edit-page-help-content.module#EditPageHelpContentModule',
    resolve: { envSpecific: EnvironmentSpecificResolver  }
  },
  {
    path: 'pages',
    loadChildren: './openaireLibrary/dashboard/page/pages.module#PagesModule',
    resolve: { envSpecific: EnvironmentSpecificResolver  }
  },
  /*{
    path: 'pages',
    loadChildren: './openaireLibrary/dashboard/page/pages.module#PagesModule',
    resolve: { envSpecific: EnvironmentSpecificResolver  }
  },
  {
    path: 'pageContents',
    loadChildren: './openaireLibrary/dashboard/helpcontent/page-help-contents.module#PageHelpContentsModule',
    resolve: { envSpecific: EnvironmentSpecificResolver  }
  },
  {
    path: 'pageContents/new',
    loadChildren: './pages/helpcontent/new-page-help-content.module#NewPageHelpContentModule',
    resolve: { envSpecific: EnvironmentSpecificResolver  }
  },
  {
    path: 'pageContents/edit',
    loadChildren: './pages/helpcontent/edit-page-help-content.module#EditPageHelpContentModule',
    resolve: { envSpecific: EnvironmentSpecificResolver  }
  },


  {
    path: 'htmlPageContent/edit',
    loadChildren: './pages/htmlpagecontent/edit-html-page-content.module#EditHtmlPageContentModule',
    resolve: { envSpecific: EnvironmentSpecificResolver  }
  },*/
  {
    path: '',
    loadChildren: './monitor/monitor.module#MonitorModule',
    resolve: {envSpecific: EnvironmentSpecificResolver},
  },
  {
    path: '**',
    pathMatch: 'full',
    component: OpenaireErrorPageComponent,
    resolve: {envSpecific: EnvironmentSpecificResolver},
    data: {hasSidebar: false}
  }
];

@NgModule({
  imports: [RouterModule.forRoot(routes, {
    preloadingStrategy: PreloadAllModules,
    scrollPositionRestoration: "top"
  })],
  exports: [RouterModule],
  providers: [EnvironmentSpecificResolver, EnvironmentSpecificService]
})
export class AppRoutingModule {
}
